==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/CannotConvertException.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_CANNOTCONVERTEXCEPTION_HPP_
#define _COM_SUN_STAR_SCRIPT_CANNOTCONVERTEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_CANNOTCONVERTEXCEPTION_HDL_
#include "com/sun/star/script/CannotConvertException.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPECLASS_HPP_
#include "com/sun/star/uno/TypeClass.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_EXCEPTION_HPP_
#include "com/sun/star/uno/Exception.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace script {

inline CannotConvertException::CannotConvertException() SAL_THROW( () )
    : ::com::sun::star::uno::Exception()
    , DestinationTypeClass(::com::sun::star::uno::TypeClass_VOID)
    , Reason(0)
    , ArgumentIndex(0)
{ }

inline CannotConvertException::CannotConvertException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::uno::TypeClass& DestinationTypeClass_, const ::sal_Int32& Reason_, const ::sal_Int32& ArgumentIndex_) SAL_THROW( () )
    : ::com::sun::star::uno::Exception(Message_, Context_)
    , DestinationTypeClass(DestinationTypeClass_)
    , Reason(Reason_)
    , ArgumentIndex(ArgumentIndex_)
{ }

CannotConvertException::CannotConvertException(CannotConvertException const & the_other): ::com::sun::star::uno::Exception(the_other), DestinationTypeClass(the_other.DestinationTypeClass), Reason(the_other.Reason), ArgumentIndex(the_other.ArgumentIndex) {}

CannotConvertException::~CannotConvertException() {}

CannotConvertException & CannotConvertException::operator =(CannotConvertException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::uno::Exception::operator =(the_other);
    DestinationTypeClass = the_other.DestinationTypeClass;
    Reason = the_other.Reason;
    ArgumentIndex = the_other.ArgumentIndex;
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::script::CannotConvertException* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.script.CannotConvertException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_SCRIPT_CANNOTCONVERTEXCEPTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/CannotConvertException.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_CANNOTCONVERTEXCEPTION_HPP_
#define _COM_SUN_STAR_SCRIPT_CANNOTCONVERTEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_CANNOTCONVERTEXCEPTION_HDL_
#include "com/sun/star/script/CannotConvertException.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPECLASS_HPP_
#include "com/sun/star/uno/TypeClass.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_EXCEPTION_HPP_
#include "com/sun/star/uno/Exception.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace script {

inline CannotConvertException::CannotConvertException() SAL_THROW( () )
    : ::com::sun::star::uno::Exception()
    , DestinationTypeClass(::com::sun::star::uno::TypeClass_VOID)
    , Reason(0)
    , ArgumentIndex(0)
{ }

inline CannotConvertException::CannotConvertException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::uno::TypeClass& DestinationTypeClass_, const ::sal_Int32& Reason_, const ::sal_Int32& ArgumentIndex_) SAL_THROW( () )
    : ::com::sun::star::uno::Exception(Message_, Context_)
    , DestinationTypeClass(DestinationTypeClass_)
    , Reason(Reason_)
    , ArgumentIndex(ArgumentIndex_)
{ }

CannotConvertException::CannotConvertException(CannotConvertException const & the_other): ::com::sun::star::uno::Exception(the_other), DestinationTypeClass(the_other.DestinationTypeClass), Reason(the_other.Reason), ArgumentIndex(the_other.ArgumentIndex) {}

CannotConvertException::~CannotConvertException() {}

CannotConvertException & CannotConvertException::operator =(CannotConvertException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::uno::Exception::operator =(the_other);
    DestinationTypeClass = the_other.DestinationTypeClass;
    Reason = the_other.Reason;
    ArgumentIndex = the_other.ArgumentIndex;
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace script {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::script::CannotConvertException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.script.CannotConvertException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::script::CannotConvertException const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::script::CannotConvertException >::get();
}

#endif // _COM_SUN_STAR_SCRIPT_CANNOTCONVERTEXCEPTION_HPP_
